@@ -9,6 +9,7 @@ from psycopg2 import connect, sql
 from fhir_cli import (
     CONNECT_CONFIG_TEMPLATE,
     CONNECT_URL,
+    CREATE_FDW_TEMPLATE,
     DBT_INIT_DB_TEMPLATE,
     DBT_META_TABLE,
     DBT_SCHEMA,
@@ -21,7 +22,14 @@ from fhir_cli import (
     POSTGRES_PORT,
     POSTGRES_SERVER_NAME,
     POSTGRES_USER,
+    PROJECT_DB,
     PROJECT_NAME,
+    SOURCE_DB,
+    SOURCE_HOST,
+    SOURCE_PASSWORD,
+    SOURCE_PORT,
+    SOURCE_TYPE,
+    SOURCE_USER,
 )
 
 
@@ -35,12 +43,8 @@ class Admin:
     """The admin command is used by an administrator to initialize a new project"""
 
     @staticmethod
-    def create(database: str):
-        """create creates a new db for the project
-
-        Args:
-            database (str): a database name of choice
-        """
+    def createdb():
+        """Create a new db for the project"""
         conn = connect(
             host=POSTGRES_HOST,
             dbname=POSTGRES_DB,
@@ -50,8 +54,8 @@ class Admin:
         )
         conn.autocommit = True
 
-        role_stmt = sql.SQL("CREATE ROLE {role}").format(role=sql.Identifier(database))
-        db_stmt = sql.SQL("CREATE DATABASE {database}").format(database=sql.Identifier(database))
+        role_stmt = sql.SQL("CREATE ROLE {role}").format(role=sql.Identifier(PROJECT_DB))
+        db_stmt = sql.SQL("CREATE DATABASE {database}").format(database=sql.Identifier(PROJECT_DB))
         with conn.cursor() as curs:
             curs.execute(role_stmt)
             curs.execute(db_stmt)
@@ -59,15 +63,11 @@ class Admin:
         conn.close()
 
     @staticmethod
-    def init(database: str):
-        """init initializes the new db for the project
-
-        Args:
-            database (str): a database name of choice
-        """
+    def initdb():
+        """Initialize the new db for the project"""
         conn = connect(
             host=POSTGRES_HOST,
-            dbname=database,
+            dbname=PROJECT_DB,
             port=POSTGRES_PORT,
             user=POSTGRES_USER,
             password=POSTGRES_PASSWORD,
@@ -79,7 +79,7 @@ class Admin:
             dbt_schema=DBT_SCHEMA,
             dbt_meta_table=DBT_META_TABLE,
             project_id=project_id,
-            role=database,
+            role=PROJECT_DB,
         )
 
         with conn.cursor() as curs:
@@ -93,14 +93,10 @@ class Admin:
         conn.close()
 
     @staticmethod
-    def connect(database: str):
-        """The connect command adds a Kafka Connect connector
-
-        Args:
-            database (str): the database Kafka Connect will listen to
-        """
+    def connect():
+        """Add a Kafka Connect connector"""
         connector = JINJA_ENV.get_template(CONNECT_CONFIG_TEMPLATE).render(
-            project_db=database,
+            project_db=PROJECT_DB,
             postgres_server_name=POSTGRES_SERVER_NAME,
             postgres_port=POSTGRES_PORT,
             postgres_user=POSTGRES_USER,
@@ -115,17 +111,16 @@ class Admin:
         r.raise_for_status()
 
     @staticmethod
-    def createuser(database: str, user: str, password: str = None):
-        """createuser adds a new user to the project
+    def createuser(user: str, password: str = None):
+        """Add a new user to the project
 
         Args:
-            database (str): the target database
             user (str): a username of choice
             password (:obj:`str`, optional): a password of choice. If not specified,
             the command will prompt for a password
         """
 
-        if not password:
+        while not password:
             password = getpass.getpass()
 
         conn = connect(
@@ -138,9 +133,51 @@ class Admin:
         conn.autocommit = True
 
         stmt = sql.SQL("CREATE USER {user} WITH PASSWORD %s IN ROLE {role}").format(
-            user=sql.Identifier(user), role=sql.Identifier(database)
+            user=sql.Identifier(user), role=sql.Identifier(PROJECT_DB)
         )
         with conn.cursor() as curs:
             curs.execute(stmt, (password,))
 
         conn.close()
+
+    @staticmethod
+    def link(source: str, target: str = None):
+        """Create a foreign schema from a schema of the source database
+
+        This command uses a foreign data wrapper that can be used to access data
+        stored in an external server. The module opens a connection and extracts
+        a database schema. Subsequently a user can import the data to the local
+        database by creating a table or a materialized view selecting from a
+        foreign table of a given schema.
+
+        Args:
+            source (str): the source schema
+            target (:obj:`str`, optional): the target schema
+        """
+        if not target:
+            target = source
+
+        conn = connect(
+            host=POSTGRES_HOST,
+            dbname=PROJECT_DB,
+            port=POSTGRES_PORT,
+            user=POSTGRES_USER,
+            password=POSTGRES_PASSWORD,
+        )
+        conn.autocommit = True
+
+        stmt = JINJA_ENV.get_template(CREATE_FDW_TEMPLATE).render(
+            source_db=SOURCE_DB,
+            source_type=SOURCE_TYPE,
+            source_host=SOURCE_HOST,
+            source_port=SOURCE_PORT,
+            source_user=SOURCE_USER,
+            source_password=SOURCE_PASSWORD,
+            project_db=PROJECT_DB,
+            source_schema=source,
+            target_schema=target,
+        )
+        with conn.cursor() as curs:
+            curs.execute(stmt)
+
+        conn.close()
