@@ -47,7 +47,7 @@ def get_resource_from_model(model: str) -> dict:
 
 
 class Cli:
-    """FhirResource cli to manage your DbtOnFhir project"""
+    """a cli to manage your DbtOnFhir project"""
 
     def __init__(self):
         self.dbt = Dbt()
@@ -55,7 +55,7 @@ class Cli:
 
     @staticmethod
     def validate(model: str):
-        """The validate method extract a fhir model row and validates the Fhir resource
+        """Extract a fhir model row and validates the Fhir resource
         against a Fhir server
 
         Args:
